@@ -168,10 +168,10 @@ class CfgSetup:
         self.cfg.set('simulation', 'CFL', '0.5')
 
         self.cfg.add_section('thermophysic')
-        self.cfg.set('thermophysic', 'rho0', '1.2')
-        self.cfg.set('thermophysic', 'c0', '340')
+        self.cfg.set('thermophysic', 'P0', '101325.0')
+        self.cfg.set('thermophysic', 'T0', '20.0')
         self.cfg.set('thermophysic', 'gamma', '1.4')
-        self.cfg.set('thermophysic', 'nu', '1.5e-5')
+        self.cfg.set('thermophysic', 'prandtl', '0.7')
 
         self.cfg.add_section('geometry')
         self.cfg.set('geometry', 'mesh', 'regular')
@@ -200,6 +200,7 @@ class CfgSetup:
         self.cfg.set('source', 'S0', '1e6')
         self.cfg.set('source', 'B0', '5')
         self.cfg.set('source', 'f0', '20000')
+        self.cfg.set('source', 'seed', 'None')
         self.cfg.set('source', 'wavfile', 'None')
 
         self.cfg.add_section('flow')
@@ -236,6 +237,7 @@ class CfgSetup:
         self.cfg.set('save', 'filename', 'tmp')
         self.cfg.set('save', 'compression', 'lzf')
         self.cfg.set('save', 'fields', 'True')
+        self.cfg.set('save', 'vorticity', 'False')
         self.cfg.set('save', 'probes', '[]')
 
         with open(self.path / 'nsfds2.conf', 'w') as cf:
@@ -299,11 +301,26 @@ class CfgSetup:
     def _thp(self):
 
         THP = self.cfg['thermophysic']
-        self.c0 = THP.getfloat('c0', 340)
-        self.rho0 = THP.getfloat('rho0', 1.22)
+
+        self.Ssu = 111.0  # Sutherland constant
+        self.T0 = 273.0
+        self.T = self.T0 + THP.getfloat('T0', 20.0)
+
         self.gamma = THP.getfloat('gamma', 1.4)
-        self.nu = THP.getfloat('nu', 1.5e-5)
-        self.p0 = self.rho0*self.c0**2/self.gamma
+        self.cv = 717.5
+        self.cp = self.cv*self.gamma
+
+        self.p0 = THP.getfloat('P0', 101325.0)
+        self.rho0 = self.p0/(self.T*(self.cp - self.cv))
+        self.c0 = (self.gamma*self.p0/self.rho0)**0.5
+        self.mu0 = 0.00001716
+        self.mu = (self.mu0*(self.T/self.T0)**(3./2.) *
+                   (self.T0 + self.Ssu)/(self.T + self.Ssu))
+        self.nu = self.mu/self.rho0
+        self.prandtl = THP.getfloat('prandtl', 0.7)
+
+#        self.nu = THP.getfloat('nu', 1.5e-5)
+#        self.p0 = self.rho0*self.c0**2/self.gamma
 
         if self.c0 < 1:
             raise ValueError('c0 must be >= 1')
@@ -421,7 +438,8 @@ class CfgSetup:
     def _save(self):
 
         SAVE = self.cfg['save']
-        self.save = SAVE.getboolean('fields', True)
+        self.save_fields = SAVE.getboolean('fields', True)
+        self.save_vortis = SAVE.getboolean('vorticity', False)
         if self.path == self.path_default:
             self.savepath = pathlib.Path(SAVE.get('path', 'results'))
         else:
